LMCache Dashboard

### Node Overview

Please select a target node first

### Performance Metrics

    Please select a target node first

### Thread Information

    Please select a target node first

### Log Level Management

Logger Name (leave empty for all)
Log Level

#### Current Log Levels

    Please select a target node first

### Node Management

##### Add/Update Node

Node Name
Host
Port/Socket Path
Is Proxy Node
Proxy ID (if this node needs proxy)

##### Current Nodes

Name | Host | Port/Socket | Actions
--- | --- | --- | ---